@@ -166,8 +166,8 @@ def _secret_redaction_processor(_, __, event_dict):
 
 
 def initialize_logger(
-    initial_context: dict | None,
-    external_logger_configurations: list[ExternalLoggerConfig] | None,
+    initial_context: dict | None = None,
+    external_logger_configurations: list[ExternalLoggerConfig] | None = None,
 ) -> None:
     """Configures logging for the application using structlog.
 
